# -*- coding: utf-8 -*-
from setuptools import setup

setup(
    name='attrs',
    version='24.1.0',
    description='Classes Without Boilerplate',
    author_email='Hynek Schlawack <hs@ox.cx>',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',
        'Programming Language :: Python :: 3.13',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy',
        'Typing :: Typed',
    ],
    install_requires=[
        'importlib-metadata; python_version < "3.8"',
    ],
    extras_require={
        'benchmark': [
            'cloudpickle; platform_python_implementation == "CPython"',
            'hypothesis',
            'mypy>=1.11.1; platform_python_implementation == "CPython" and python_version >= "3.9"',
            'pympler',
            'pytest-codspeed',
            'pytest-mypy-plugins; platform_python_implementation == "CPython" and python_version >= "3.9" and python_version < "3.13"',
            'pytest-xdist[psutil]',
            'pytest>=4.3.0',
        ],
        'cov': [
            'cloudpickle; platform_python_implementation == "CPython"',
            'coverage[toml]>=5.3',
            'hypothesis',
            'mypy>=1.11.1; platform_python_implementation == "CPython" and python_version >= "3.9"',
            'pympler',
            'pytest-mypy-plugins; platform_python_implementation == "CPython" and python_version >= "3.9" and python_version < "3.13"',
            'pytest-xdist[psutil]',
            'pytest>=4.3.0',
        ],
        'dev': [
            'cloudpickle; platform_python_implementation == "CPython"',
            'hypothesis',
            'mypy>=1.11.1; platform_python_implementation == "CPython" and python_version >= "3.9"',
            'pre-commit',
            'pympler',
            'pytest-mypy-plugins; platform_python_implementation == "CPython" and python_version >= "3.9" and python_version < "3.13"',
            'pytest-xdist[psutil]',
            'pytest>=4.3.0',
        ],
        'docs': [
            'cogapp',
            'furo',
            'myst-parser',
            'sphinx',
            'sphinx-notfound-page',
            'sphinxcontrib-towncrier',
            'towncrier<24.7',
        ],
        'tests': [
            'cloudpickle; platform_python_implementation == "CPython"',
            'hypothesis',
            'mypy>=1.11.1; platform_python_implementation == "CPython" and python_version >= "3.9"',
            'pympler',
            'pytest-mypy-plugins; platform_python_implementation == "CPython" and python_version >= "3.9" and python_version < "3.13"',
            'pytest-xdist[psutil]',
            'pytest>=4.3.0',
        ],
        'tests-mypy': [
            'mypy>=1.11.1; platform_python_implementation == "CPython" and python_version >= "3.9"',
            'pytest-mypy-plugins; platform_python_implementation == "CPython" and python_version >= "3.9" and python_version < "3.13"',
        ],
    },
    packages=[
        'attr',
        'attrs',
    ],
    package_dir={'': 'src'},
)
